<?php

declare(strict_types=1);

namespace Drupal\environment_config_split\EventSubscriber;

use Drupal\config_split\ConfigSplitManager;
use Drupal\environment_context\Event\AvailableEnvironmentsEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Adds config splits as environments to Environment Context.
 */
class ConfigSplitEnvironmentSubscriber implements EventSubscriberInterface {

  /**
   * Constructs the subscriber.
   */
  public function __construct(protected ConfigSplitManager $splitManager) {}

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      AvailableEnvironmentsEvent::EVENT_NAME => 'onAvailableEnvironments',
    ];
  }

  /**
   * Registers all config split names as environments.
   */
  public function onAvailableEnvironments(AvailableEnvironmentsEvent $event): void {
    $all = $this->splitManager->listAll();
    foreach ($this->splitManager->loadMultiple($all) as $split_name => $config) {
      $event->addEnvironment($config->get('id'), $config->get('label'));
    }
  }

}
