<?php

declare(strict_types=1);

namespace Drupal\environment_context\Cache;

use Drupal\Core\Cache\CacheableMetadata;
use Drupal\Core\Cache\Context\CacheContextInterface;
use Drupal\environment_context\ContextProvider\EnvironmentResolverInterface;

/**
 * Defines the 'environment' cache context.
 *
 * Allows caching to vary by current runtime environment.
 */
class EnvironmentCacheContext implements CacheContextInterface {

  /**
   * Constructs the cache context.
   *
   * @param \Drupal\environment_context\ContextProvider\EnvironmentResolverInterface $resolver
   *   The environment resolver service.
   */
  public function __construct(
    protected readonly EnvironmentResolverInterface $resolver,
  ) {}

  /**
   * {@inheritdoc}
   */
  public static function getLabel(): string {
    return t('Environment')->__toString();
  }

  /**
   * {@inheritdoc}
   */
  public function getContext(): string {
    return $this->resolver->getCurrentEnvironment();
  }

  /**
   * {@inheritdoc}
   */
  public function getCacheableMetadata(): CacheableMetadata {
    return new CacheableMetadata();
  }

}
