<?php

declare(strict_types=1);

namespace Drupal\environment_context\ContextProvider;

use Drupal\Core\Plugin\Context\Context;
use Drupal\Core\Plugin\Context\ContextDefinition;
use Drupal\Core\Plugin\Context\ContextProviderInterface;
use Drupal\environment_context\Environment\EnvironmentRegistryInterface;
use Drupal\environment_context\Event\EnvironmentDetectionEvent;
use Symfony\Contracts\EventDispatcher\EventDispatcherInterface;

/**
 * The environment context provider.
 */
class EnvironmentContext implements ContextProviderInterface, EnvironmentResolverInterface {

  /**
   * The current environment.
   *
   * @var string
   */
  protected string $environment = EnvironmentRegistryInterface::DEFAULT_ENVIRONMENT_KEY;

  /**
   * Makes sure the event only gets dispatched once.
   *
   * @var bool
   */
  protected bool $eventDispatched = FALSE;

  /**
   * Constructs a EnvironmentContext object.
   *
   * @param \Symfony\Contracts\EventDispatcher\EventDispatcherInterface $eventDispatcher
   *   Event dispatcher.
   */
  public function __construct(
    protected readonly EventDispatcherInterface $eventDispatcher,
  ) {}

  /**
   * {@inheritdoc}
   */
  public function getRuntimeContexts(array $unqualified_context_ids): array {
    return ['environment' => new Context(new ContextDefinition('environment', 'Environment'), $this->getCurrentEnvironment())];
  }

  /**
   * {@inheritdoc}
   */
  public function getAvailableContexts(): array {
    return [
      'environment' => new Context(new ContextDefinition('environment', 'Environment name')),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getCurrentEnvironment(): string {
    if ($this->environment == EnvironmentRegistryInterface::DEFAULT_ENVIRONMENT_KEY && !$this->eventDispatched) {
      $event = new EnvironmentDetectionEvent();
      $this->eventDispatcher->dispatch($event, EnvironmentDetectionEvent::EVENT_NAME);
      $this->environment = $event->getEnvironment() ?? EnvironmentRegistryInterface::DEFAULT_ENVIRONMENT_KEY;
      $this->eventDispatched = TRUE;
    }

    return $this->environment;
  }

}
