<?php

declare(strict_types=1);

namespace Drupal\environment_context\Environment;

use Symfony\Component\EventDispatcher\EventDispatcherInterface;
use Drupal\environment_context\Event\AvailableEnvironmentsEvent;

/**
 * Service that provides a list of available environments.
 */
class EnvironmentRegistry implements EnvironmentRegistryInterface {

  /**
   * The event dispatcher service.
   *
   * @var \Symfony\Component\EventDispatcher\EventDispatcherInterface
   */
  protected EventDispatcherInterface $eventDispatcher;

  /**
   * Constructs the environment registry.
   *
   * @param \Symfony\Component\EventDispatcher\EventDispatcherInterface $event_dispatcher
   *   The event dispatcher.
   */
  public function __construct(EventDispatcherInterface $event_dispatcher) {
    $this->eventDispatcher = $event_dispatcher;
  }

  /**
   * {@inheritdoc}
   */
  public function getAvailableEnvironments(): array {
    return array_keys($this->getEnvironmentDefinitions());
  }

  /**
   * {@inheritdoc}
   */
  public function getEnvironmentDefinitions(): array {
    $event = new AvailableEnvironmentsEvent();
    $this->eventDispatcher->dispatch($event, AvailableEnvironmentsEvent::EVENT_NAME);
    return $event->getEnvironments();
  }

  /**
   * {@inheritdoc}
   */
  public function getDefinition(string $machine_name): ?array {
    $definitions = $this->getEnvironmentDefinitions();
    return $definitions[$machine_name] ?? NULL;
  }

  /**
   * {@inheritdoc}
   */
  public function getEnvironmentOptions(): array {
    $options = [EnvironmentRegistryInterface::DEFAULT_ENVIRONMENT_KEY => t('Default')];
    foreach ($this->getEnvironmentDefinitions() as $environment => $definition) {
      $options[$environment] = $definition['label'];
    }

    return $options;
  }

}
