<?php

namespace Drupal\environment_context\Environment;

/**
 * Provides an interface for accessing environment definitions.
 */
interface EnvironmentRegistryInterface {

  /**
   * The default environment key.
   */
  public const DEFAULT_ENVIRONMENT_KEY = 'default';

  /**
   * Returns all known environment machine names.
   *
   * @return string[]
   *   An array of environment keys.
   */
  public function getAvailableEnvironments(): array;

  /**
   * Returns metadata for all available environments.
   *
   * @return array[]
   *   An associative array of environment definitions.
   */
  public function getEnvironmentDefinitions(): array;

  /**
   * Returns metadata for a single environment.
   *
   * @param string $machine_name
   *   The environment key.
   *
   * @return array|null
   *   The definition array or NULL if not found.
   */
  public function getDefinition(string $machine_name): ?array;

  /**
   * Builds and options array for environment options.
   *
   * @return array
   *   The environment options including default one.
   */
  public function getEnvironmentOptions(): array;

}
