<?php

declare(strict_types=1);

namespace Drupal\environment_context\Event;

use Symfony\Contracts\EventDispatcher\Event;

/**
 * Event used to determine the current runtime environment.
 *
 * Listeners can set the current environment using setEnvironment().
 */
class EnvironmentDetectionEvent extends Event {

  /**
   * The event name for environment detection.
   *
   * @var string
   */
  public const EVENT_NAME = 'environment_context.detect';

  /**
   * The detected environment name.
   *
   * @var string|null
   */
  protected ?string $environment = NULL;

  /**
   * Gets the current environment.
   *
   * @return string|null
   *   The environment name or NULL if none was set.
   */
  public function getEnvironment(): ?string {
    return $this->environment;
  }

  /**
   * Sets the detected environment name.
   *
   * @param string $environment
   *   The machine name of the environment.
   */
  public function setEnvironment(string $environment): void {
    $this->environment = $environment;
  }

}
