<?php

declare(strict_types=1);

namespace Drupal\environment_context\EventSubscriber;

use Drupal\Core\Site\Settings;
use Drupal\environment_context\Event\EnvironmentDetectionEvent;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Provides default environment detection logic.
 */
class DefaultEnvironmentDetector implements EventSubscriberInterface {

  /**
   * The request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected RequestStack $requestStack;

  /**
   * Constructs the detector.
   *
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The request stack.
   */
  public function __construct(RequestStack $request_stack) {
    $this->requestStack = $request_stack;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    return [
      EnvironmentDetectionEvent::EVENT_NAME => 'onDetectEnvironment',
    ];
  }

  /**
   * Sets a default environment based on hostname or env var.
   *
   * @param \Drupal\environment_context\Event\EnvironmentDetectionEvent $event
   *   The environment detection event.
   */
  public function onDetectEnvironment(EnvironmentDetectionEvent $event): void {
    // Support settings based environments.
    if ($env = Settings::get('environment', NULL)) {
      $event->setEnvironment($env);
      return;
    }

    // Support .env based environments.
    if ($env = getenv('DRUPAL_ENVIRONMENT')) {
      $event->setEnvironment($env);
      return;
    }
  }

}
