<?php

declare(strict_types=1);

namespace Drupal\environment_context\Plugin\DataType;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\TypedData\Attribute\DataType;
use Drupal\Core\TypedData\Plugin\DataType\StringData;

/**
 * The "environment" data type.
 */
#[DataType(
  id: "environment",
  label: new TranslatableMarkup('Environment'),
)]
class Environment extends StringData {

  /**
   * Checks if the value is a known environment.
   *
   * @return bool
   *   TRUE if valid, FALSE otherwise.
   */
  public function isValid(): bool {
    $registry = \Drupal::service('environment_context.registry');
    return in_array($this->value, $registry->getAvailableEnvironments(), TRUE);
  }

  /**
   * Returns the environment name.
   *
   * @return string
   *   The environment string.
   */
  public function getEnvironment(): string {
    return $this->getValue();
  }

}
