<?php

declare(strict_types=1);

namespace Drupal\Tests\environment_context\Kernel;

use Drupal\Core\Plugin\Context\ContextInterface;
use Drupal\environment_context\Event\EnvironmentDetectionEvent;
use Drupal\KernelTests\KernelTestBase;

/**
 * @coversDefaultClass \\Drupal\\environment_context\\ContextProvider\\EnvironmentContext
 * @group environment_context
 */
class EnvironmentContextTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'system',
    'environment_context',
  ];

  /**
   * Tests the context resolution and typed data plugin integration.
   */
  public function testGetRuntimeContexts(): void {
    // Register a test environment via event listener.
    $dispatcher = $this->container->get('event_dispatcher');
    $dispatcher->addListener(EnvironmentDetectionEvent::EVENT_NAME, function (EnvironmentDetectionEvent $event) {
      $event->setEnvironment('staging');
    });

    /** @var \Drupal\environment_context\ContextProvider\EnvironmentContext $provider */
    $provider = $this->container->get('environment_context.context.environment');
    $contexts = $provider->getRuntimeContexts([]);

    $this->assertArrayHasKey('environment', $contexts);
    $this->assertInstanceOf(ContextInterface::class, $contexts['environment']);
    $this->assertSame('staging', $contexts['environment']->getContextValue());
  }

}
