<?php

declare(strict_types=1);

namespace Drupal\Tests\environment_context\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Drupal\environment_context\Event\AvailableEnvironmentsEvent;

/**
 * Tests the "environment" data type plugin.
 *
 * @group environment_context
 */
class EnvironmentDataTypeTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'system',
    'user',
    'environment_context',
  ];

  /**
   * Tests isValid() and getEnvironment().
   */
  public function testEnvironmentDataType(): void {
    // Register known environments.
    $this->container->get('event_dispatcher')->addListener(
      AvailableEnvironmentsEvent::EVENT_NAME,
      static function (AvailableEnvironmentsEvent $event) {
        $event->addEnvironment('testing', ['label' => 'Testing']);
        $event->addEnvironment('prod', ['label' => 'Production']);
      }
    );

    /** @var \Drupal\Core\TypedData\TypedDataManagerInterface $typed_data_manager */
    $typed_data_manager = $this->container->get('typed_data_manager');

    $definition = $typed_data_manager->getDefinition('environment');
    $this->assertSame('Environment', (string) $definition['label']);

    $typed_data = $typed_data_manager->createDataDefinition('environment');
    $environment = $typed_data_manager->create($typed_data, 'testing');

    $this->assertTrue($environment->isValid(), 'Valid environment is recognized.');
    $this->assertSame('testing', $environment->getEnvironment());

    // Now test invalid environment.
    $invalid = $typed_data_manager->create($typed_data, 'invalid_env');
    $this->assertFalse($invalid->isValid(), 'Unknown environment is not valid.');
  }

}
