<?php

declare(strict_types=1);

namespace Drupal\Tests\environment_context\Unit;

use Drupal\Core\Site\Settings;
use Drupal\environment_context\Event\EnvironmentDetectionEvent;
use Drupal\environment_context\EventSubscriber\DefaultEnvironmentDetector;
use PHPUnit\Framework\TestCase;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * @coversDefaultClass \\Drupal\\environment_context\\EventSubscriber\\DefaultEnvironmentDetector
 * @group environment_context
 */
class DefaultEnvironmentDetectorTest extends TestCase {

  /**
   * @covers ::onDetectEnvironment
   */
  public function testDetectEnvironmentFromSettings(): void {
    new Settings(['environment' => 'testing']);
    $stack = new RequestStack();

    $subscriber = new DefaultEnvironmentDetector($stack);
    $event = new EnvironmentDetectionEvent();
    $subscriber->onDetectEnvironment($event);

    $this->assertSame('testing', $event->getEnvironment());
    // Cleanup for other tests.
    new Settings([]);
  }

  /**
   * @covers ::onDetectEnvironment
   */
  public function testDetectEnvironmentFromEnvVar(): void {
    putenv('DRUPAL_ENVIRONMENT=ci');

    $stack = new RequestStack();
    $subscriber = new DefaultEnvironmentDetector($stack);
    $event = new EnvironmentDetectionEvent();
    $subscriber->onDetectEnvironment($event);

    $this->assertSame('ci', $event->getEnvironment());

    // Cleanup for other tests.
    putenv('DRUPAL_ENVIRONMENT');
  }

  /**
   * @covers ::onDetectEnvironment
   */
  public function testNoEnvironmentDetected(): void {
    // Make sure no environment is set.
    putenv('DRUPAL_ENVIRONMENT');
    $stack = new RequestStack();

    $subscriber = new DefaultEnvironmentDetector($stack);
    $event = new EnvironmentDetectionEvent();
    $subscriber->onDetectEnvironment($event);

    $this->assertNull($event->getEnvironment());
  }

}
