<?php

declare(strict_types=1);

namespace Drupal\Tests\environment_context\Unit;

use Drupal\environment_context\Environment\EnvironmentRegistry;
use Drupal\environment_context\Event\AvailableEnvironmentsEvent;
use PHPUnit\Framework\TestCase;
use Symfony\Component\EventDispatcher\EventDispatcherInterface;

/**
 * @coversDefaultClass \\Drupal\\environment_context\\Environment\\EnvironmentRegistry
 * @group environment_context
 */
class EnvironmentRegistryTest extends TestCase {

  /**
   * @covers ::getAvailableEnvironments
   * @covers ::getEnvironmentDefinitions
   * @covers ::getDefinition
   */
  public function testEnvironmentDefinitions(): void {
    // Mock the event dispatcher to inject a known environment.
    $dispatcher = $this->createMock(EventDispatcherInterface::class);
    $dispatcher
      ->expects($this->any())
      ->method('dispatch')
      ->willReturnCallback(function ($event, string $eventName) {
        assert($event instanceof AvailableEnvironmentsEvent);
        $event->addEnvironment('local', ['label' => 'Local Dev']);
        return $event;
      });

    $registry = new EnvironmentRegistry($dispatcher);

    $environments = $registry->getAvailableEnvironments();
    $definitions = $registry->getEnvironmentDefinitions();
    $local = $registry->getDefinition('local');

    $this->assertContains('local', $environments);
    $this->assertArrayHasKey('local', $definitions);
    $this->assertEquals('Local Dev', $local['label']);
  }

}
